package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletRealizationProject;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 变现项目Mapper接口
 *
 * @author clunt
 * @date 2024-03-10
 */
public interface PlayletRealizationProjectMapper extends BaseMapper<PlayletRealizationProject>
{
    /**
     * 查询变现项目
     *
     * @param id 变现项目主键
     * @return 变现项目
     */
    public PlayletRealizationProject selectPlayletRealizationProjectById(Long id);

    /**
     * 查询变现项目列表
     *
     * @param playletRealizationProject 变现项目
     * @return 变现项目集合
     */
    public List<PlayletRealizationProject> selectPlayletRealizationProjectList(PlayletRealizationProject playletRealizationProject);

    /**
     * 新增变现项目
     *
     * @param playletRealizationProject 变现项目
     * @return 结果
     */
    public int insertPlayletRealizationProject(PlayletRealizationProject playletRealizationProject);

    /**
     * 修改变现项目
     *
     * @param playletRealizationProject 变现项目
     * @return 结果
     */
    public int updatePlayletRealizationProject(PlayletRealizationProject playletRealizationProject);

    /**
     * 删除变现项目
     *
     * @param id 变现项目主键
     * @return 结果
     */
    public int deletePlayletRealizationProjectById(Long id);

    /**
     * 批量删除变现项目
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletRealizationProjectByIds(String[] ids);
}
